@@ -192,7 +192,6 @@ class TokenType(AutoName):
     BIGSERIAL = auto()
     XML = auto()
     YEAR = auto()
-    UNIQUEIDENTIFIER = auto()
     USERDEFINED = auto()
     MONEY = auto()
     SMALLMONEY = auto()
@@ -250,6 +249,7 @@ class TokenType(AutoName):
     CUBE = auto()
     CURRENT_DATE = auto()
     CURRENT_DATETIME = auto()
+    CURRENT_SCHEMA = auto()
     CURRENT_TIME = auto()
     CURRENT_TIMESTAMP = auto()
     CURRENT_USER = auto()
@@ -413,6 +413,7 @@ class TokenType(AutoName):
     SOURCE = auto()
     ANALYZE = auto()
     NAMESPACE = auto()
+    EXPORT = auto()
 
 
 _ALL_TOKEN_TYPES = list(TokenType)
@@ -713,6 +714,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "CROSS": TokenType.CROSS,
         "CUBE": TokenType.CUBE,
         "CURRENT_DATE": TokenType.CURRENT_DATE,
+        "CURRENT_SCHEMA": TokenType.CURRENT_SCHEMA,
         "CURRENT_TIME": TokenType.CURRENT_TIME,
         "CURRENT_TIMESTAMP": TokenType.CURRENT_TIMESTAMP,
         "CURRENT_USER": TokenType.CURRENT_USER,
@@ -854,7 +856,6 @@ class Tokenizer(metaclass=_Tokenizer):
         "INT16": TokenType.SMALLINT,
         "SHORT": TokenType.SMALLINT,
         "SMALLINT": TokenType.SMALLINT,
-        "INT128": TokenType.INT128,
         "HUGEINT": TokenType.INT128,
         "UHUGEINT": TokenType.UINT128,
         "INT2": TokenType.SMALLINT,
@@ -863,10 +864,14 @@ class Tokenizer(metaclass=_Tokenizer):
         "INT4": TokenType.INT,
         "INT32": TokenType.INT,
         "INT64": TokenType.BIGINT,
+        "INT128": TokenType.INT128,
+        "INT256": TokenType.INT256,
         "LONG": TokenType.BIGINT,
         "BIGINT": TokenType.BIGINT,
         "INT8": TokenType.TINYINT,
         "UINT": TokenType.UINT,
+        "UINT128": TokenType.UINT128,
+        "UINT256": TokenType.UINT256,
         "DEC": TokenType.DECIMAL,
         "DECIMAL": TokenType.DECIMAL,
         "DECIMAL32": TokenType.DECIMAL32,
