@@ -885,3 +885,7 @@ SELECT attach
 SELECT detach
 SELECT 1 OFFSET 1
 SELECT 1 LIMIT 1
+CAST(x AS INT128)
+CAST(x AS UINT128)
+CAST(x AS UINT256)
+SELECT export
\ No newline at end of file
