@@ -307,3 +307,11 @@ ARRAY<STRING>;
 # dialect: bigquery
 SPLIT(tbl.bin_col, delim);
 ARRAY<BINARY>;
+
+# dialect: bigquery
+STRING(json_expr);
+STRING;
+
+# dialect: bigquery
+STRING(timestamp_expr, timezone);
+STRING;
\ No newline at end of file
